==> robomotion_app_lib-0.1.0.tar.gz: lib/dialog_block.dart <==
import 'package:flutter/material.dart';
import 'package:robomotion_app_lib/parser.dart';
import 'dart:convert';

//ignore: must_be_immutable
class DialogBlock extends StatefulWidget {
  final String block;
  final bool disabled;

  ButtonParser buttonParser = ButtonParser();
  DividerParser dividerParser = DividerParser();
  HeaderParser headerParser = HeaderParser();
  ImageParser imageParser = ImageParser();
  SectionParser sectionParser = SectionParser();
  SpacerParser spacerParser = SpacerParser();
  DragDropParser dragDropParser = DragDropParser();

  DialogBlock(this.block,
      {buttonParser,
      dividerParser,
      headerParser,
      imageParser,
      sectionParser,
      spacerParser,
      dragDropParser,
      this.disabled = false}) {
    if (buttonParser != null) this.buttonParser = buttonParser;
    if (dividerParser != null) this.dividerParser = dividerParser;
    if (headerParser != null) this.headerParser = headerParser;
    if (imageParser != null) this.imageParser = imageParser;
    if (sectionParser != null) this.sectionParser = sectionParser;
    if (spacerParser != null) this.spacerParser = spacerParser;
    if (dragDropParser != null) this.dragDropParser = dragDropParser;
  }

  @override
  createState() => DialogBlockState();
}

class DialogBlockState extends State<DialogBlock> {
  List<Widget> renderBlock(BuildContext context) {
    var json = jsonDecode(widget.block);
    List<Widget> widgets = [];

    for (var block in json["blocks"]) {
      var blockType = block["type"];
      Widget widget;
      switch (blockType) {
        case "section":
          widget = renderSectionBlock(context, block);
          break;

        case "actions":
          widget = renderActionsBlock(context, block);
          break;

        case "divider":
          widget = renderDividerBlock(context, block);
          break;

        case "image":
          widget = renderImageBlock(context, block);
          break;

        case "context":
          widget = renderContextBlock(context, block);
          break;

        case "header":
          widget = renderHeaderBlock(context, block);
          break;

        case "file":
          widget = renderFileBlock(context, block);
          break;
      }

      if (widget != null) {
        widgets.add(widget);
      }
    }

    return widgets;
  }

  Widget renderSectionBlock(BuildContext context, block) {
    return widget.sectionParser.parse(block, context: context);
  }

  Widget renderActionsBlock(BuildContext context, block) {
    List elements = block["elements"];
    List<Widget> actionWidgets = [];

    int i = 0;
    for (Map element in elements) {
      switch (element["type"]) {
        case "button":
          var mL = i == 0 ? 0.0 : 8.0;
          var mR = i == elements.length - 1 ? 0.0 : 8.0;
          actionWidgets.add(widget.buttonParser.parse(element,
              context: context,
              options: Options(margin: EdgeInsets.fromLTRB(mL, 8, mR, 8), disabled: widget.disabled)));
          break;

        case "spacer":
          actionWidgets.add(widget.spacerParser.parse(element, context: context));
          break;

        case "file":
          actionWidgets.add(renderFileBlock(context, element));
          break;

        default:
          break;
      }
      i++;
    }

    return Row(
      children: actionWidgets,
    );
  }

  Widget renderDividerBlock(BuildContext context, block) {
    return widget.dividerParser.parse(block, context: context);
  }

  Widget renderImageBlock(BuildContext context, block) {
    return widget.imageParser.parse(block, context: context);
  }

  Widget renderContextBlock(BuildContext context, block) {
    return Container();
  }

  Widget renderHeaderBlock(BuildContext context, block) {
    return widget.headerParser.parse(block, context: context);
  }

  Widget renderFileBlock(BuildContext context, block) {
    var file = block["file"];
    var innerType = file["type"];
    switch (innerType) {
      case "drag_drop":
        return widget.dragDropParser.parse(block, context: context, options: Options(disabled: widget.disabled));
    }

    return Container();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.all(16),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: renderBlock(context),
      ),
    );
  }
}

==> robomotion_app_lib-0.1.16.tar.gz: lib/dialog_block.dart <==
import 'package:flutter/material.dart';
import 'package:robomotion_app_lib/parser.dart';
import 'dart:convert';

//ignore: must_be_immutable
class DialogBlock extends StatefulWidget {
  final String block;
  final bool disabled;

  ButtonParser buttonParser = ButtonParser();
  DividerParser dividerParser = DividerParser();
  HeaderParser headerParser = HeaderParser();
  ImageParser imageParser = ImageParser();
  SectionParser sectionParser = SectionParser();
  SpacerParser spacerParser = SpacerParser();
  DragDropParser dragDropParser = DragDropParser();
  PlainTextInputParser plainTextInputParser = PlainTextInputParser();

  DialogBlock(this.block,
      {buttonParser,
      dividerParser,
      headerParser,
      imageParser,
      sectionParser,
      spacerParser,
      dragDropParser,
      plainTextInputParser,
      this.disabled = false}) {
    this.buttonParser = buttonParser ?? this.buttonParser;
    this.dividerParser = dividerParser ?? this.dividerParser;
    this.headerParser = headerParser ?? this.headerParser;
    this.imageParser = imageParser ?? this.imageParser;
    this.sectionParser = sectionParser ?? this.sectionParser;
    this.spacerParser = spacerParser ?? this.spacerParser;
    this.dragDropParser = dragDropParser ?? this.dragDropParser;
    this.plainTextInputParser = plainTextInputParser ?? this.plainTextInputParser;
  }

  @override
  createState() => DialogBlockState();
}

class DialogBlockState extends State<DialogBlock> {
  List<Widget> renderBlock(BuildContext context) {
    var json = jsonDecode(widget.block);
    List<Widget> widgets = [];

    for (var block in json["blocks"]) {
      var blockType = block["type"];
      Widget widget;
      switch (blockType) {
        case "section":
          widget = renderSectionBlock(context, block);
          break;

        case "actions":
          widget = renderActionsBlock(context, block);
          break;

        case "divider":
          widget = renderDividerBlock(context, block);
          break;

        case "image":
          widget = renderImageBlock(context, block);
          break;

        case "context":
          widget = renderContextBlock(context, block);
          break;

        case "header":
          widget = renderHeaderBlock(context, block);
          break;

        case "file":
          widget = renderFileBlock(context, block);
          break;

        case "input":
          widget = renderInputBlock(context, block);
          break;
      }

      if (widget != null) {
        widgets.add(widget);
      }
    }

    return widgets;
  }

  Widget renderSectionBlock(BuildContext context, block) {
    return widget.sectionParser.parse(block, context: context);
  }

  Widget renderActionsBlock(BuildContext context, block) {
    List elements = block["elements"];
    List<Widget> actionWidgets = [];

    int i = 0;
    for (Map element in elements) {
      switch (element["type"]) {
        case "button":
          var mL = i == 0 ? 0.0 : 8.0;
          var mR = i == elements.length - 1 ? 0.0 : 8.0;
          actionWidgets.add(widget.buttonParser.parse(element,
              context: context,
              options: Options(margin: EdgeInsets.fromLTRB(mL, 8, mR, 8), disabled: widget.disabled)));
          break;

        case "spacer":
          actionWidgets.add(widget.spacerParser.parse(element, context: context));
          break;

        case "file":
          actionWidgets.add(renderFileBlock(context, element));
          break;

        default:
          break;
      }
      i++;
    }

    return Row(
      children: actionWidgets,
    );
  }

  Widget renderDividerBlock(BuildContext context, block) {
    return widget.dividerParser.parse(block, context: context);
  }

  Widget renderImageBlock(BuildContext context, block) {
    return widget.imageParser.parse(block, context: context);
  }

  Widget renderContextBlock(BuildContext context, block) {
    return Container();
  }

  Widget renderHeaderBlock(BuildContext context, block) {
    return widget.headerParser.parse(block, context: context);
  }

  Widget renderFileBlock(BuildContext context, block) {
    var file = block["file"];
    var innerType = file["type"];
    switch (innerType) {
      case "drag_drop":
        return widget.dragDropParser.parse(block, context: context, options: Options(disabled: widget.disabled));
    }

    return Container();
  }

  Widget renderInputBlock(BuildContext context, block) {
    var element = block["element"];
    var innerType = element["type"];

    switch (innerType) {
      case "plain_text_input":
        return widget.plainTextInputParser.parse(block, context: context, options: Options(disabled: widget.disabled));
    }

    return Container();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.all(16),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: renderBlock(context),
      ),
    );
  }
}
